=======
Poultry
=======

Poultry is a tweet collection manager.

.. include:: user_guide.rst

Table of contents
=================

.. toctree::
   :maxdepth: 3

   dev_guide

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

